@@ -87,13 +87,13 @@ class Converter:
         if Converter._nlp is None:
             try:
                 # Load spaCy without any unnecessary components
-                Converter._nlp = spacy.load('en', disable=['parser', 'ner'])
+                Converter._nlp = spacy.load('en_core_web_sm', disable=['parser', 'ner'])
             except OSError:
                 printmsg('Downloading language model for the spaCy POS tagger\n'
                          "(don't worry, this will only happen once)")
-                from spacy.cli import download
-                download('en')
-                Converter._nlp = spacy.load('en', disable=['parser', 'ner'])
+                from spacy.cli import download  # pylint: disable=import-outside-toplevel
+                download('en_core_web_sm')
+                Converter._nlp = spacy.load('en_core_web_sm', disable=['parser', 'ner'])
 
     @staticmethod
     def tokenize_text(text: str) -> List[str]:
@@ -495,8 +495,13 @@ class Converter:
         If the element lives within the XHTML namespace, just the local name is returned,
         e.g. '{http://www.w3.org/1999/xhtml}img' becomes 'img'.
 
+        If the element is a comment or PI, None is returned.
+
         In all other cases, the tag name is returned unchanged.
         """
+        if isinstance(elem, (etree._Comment, etree._ProcessingInstruction)):
+            return None
+
         tag = elem.tag
 
         if tag is None:
