@@ -6,6 +6,7 @@ import os
 from os import path
 import logging
 import re
+import string
 from time import time
 
 from typing import Match, NamedTuple, Optional, Sequence, Tuple
@@ -15,6 +16,7 @@ from uuid import uuid4
 
 from flask import (Flask, flash, make_response, Markup, render_template, request, redirect,
                    send_file, send_from_directory)
+from flask.logging import create_logger
 import misaka
 from werkzeug.utils import secure_filename
 from werkzeug.wrappers import Response
@@ -61,6 +63,25 @@ def hexify_string(text: str) -> str:
     """Replace each character in a string by the corresponding HTML character entity."""
     return ''.join('&#x{:x};'.format(ord(c)) for c in text)
 
+def text_to_id(text: str) -> str:
+    """Convert a text (section title or similar) into an ID.
+
+    * Punctuation and outer whitespace is stripped.
+    * Each inner whitespace sequence is converted to a hyphen.
+    * Letters are converted to lowercase.
+    """
+    text = text.strip().lower()
+    text = text.translate(str.maketrans('', '', string.punctuation))
+    return '-'.join(text.split())
+
+def add_section_anchor(matchobj: Match) -> str:
+    """Add anchors (IDs) to section headers.
+
+    Note: This is quite simple and will NOT handle repeated sections with the same title
+    correctly.
+    """
+    idtext = text_to_id(matchobj.group(1))
+    return matchobj.group(0).replace('>', f' id="{idtext}">', 1)
 
 def protect_mailto(matchobj: Match) -> str:
     """Helper function that spam-protects mailto links."""
@@ -88,9 +109,12 @@ def markdown_markup(text: str,
 
     html = (misaka.smartypants(misaka.html(text))
             .replace('&#39;', '&rsquo;')  # smartypants sometimes gets this wrong
+            .replace('&reg;', '(r)')      # revert unwanted replacement
             .replace('<blockquote>', '<blockquote class="alert alert-secondary">')
             .replace('<pre>', '<pre class="alert alert-primary">'))
 
+    # Add anchors to section headers
+    html = re.sub('<h2>(.*?)</h2>', add_section_anchor, html)
     if protect_email_addresses:
         html = re.sub('<a href="mailto:([^"]+)">([^<]+)</a>', protect_mailto, html)
     return Markup(html)
@@ -111,31 +135,19 @@ def build_page_dict() -> 'OrderedDict[str, PageData]':
     # pylint: disable=too-many-locals
     result = OrderedDict()  # type: OrderedDict[str, PageData]
     readme = readfile('README.md')
-    idea, rest = split_at(readme, '## Conventions')
+    idea, rest = split_at(readme, '## The Rules of Lytspel')
     # Replace title
     title = 'Idea and Motivation'
     idea = replace_first_line(idea, '# ' + title)
     result['idea'] = PageData(title, markdown_markup(idea))
 
     # We render this file now so it will be inserted into the navbar in the desired place
-    overview = readfile('docs/lytspel-on-one-page.md')
+    overview = readfile('docs/lytspel-on-two-pages.md')
     overview = replace_first_line(overview, '# Lytspel in Brief')
     result['overview'] = PageData('Brief Overview', markdown_markup(overview))
 
     # Returning to the README
     rules, rest = split_at(rest, '## International')
-    # Move the second section header in the Rules fragment up, replacing the first one
-    rulelines = rules.splitlines()
-    idx = 0
-    for idx, line in enumerate(rulelines):
-        if idx and line.startswith('## '):
-            break
-    if idx:
-        header_line = rulelines.pop(idx)
-        rulelines[0] = header_line
-    rules = '\n'.join(rulelines)
-    # Boldface first "stress"
-    rules = rules.replace('stress', '**stress**', 1)
     result['rules'] = PageData('Complete Ruleset', markdown_markup(rules, move_headers_up=True))
 
     intl, rest = split_at(rest, '## Limitations')
@@ -253,6 +265,7 @@ SERVER_SOFTWARE = os.environ.get('SERVER_SOFTWARE', 'flask')
 
 app = Flask(__name__)  # pylint: disable=invalid-name
 app.config.from_pyfile('web.cfg')
+LOG = create_logger(app)
 
 # Set suitable default values
 app.config.setdefault('UPLOAD_FOLDER', HOME + '/webdata/uploads')
@@ -260,10 +273,10 @@ app.config.setdefault('UPLOAD_FOLDER', HOME + '/webdata/uploads')
 # Configure logging
 if 'gunicorn' in SERVER_SOFTWARE:
     gunicorn_logger = logging.getLogger('gunicorn.error')  # pylint: disable=invalid-name
-    app.logger.handlers = gunicorn_logger.handlers
-    app.logger.setLevel(gunicorn_logger.level)
+    LOG.handlers = gunicorn_logger.handlers
+    LOG.setLevel(gunicorn_logger.level)
 
-app.logger.info('App ready to serve under %s', SERVER_SOFTWARE)
+LOG.info('App ready to serve under %s', SERVER_SOFTWARE)
 
 
 @app.before_request
@@ -393,11 +406,11 @@ def favicon() -> Response:
     return redirect('/static/favicon.ico')
 
 
-@app.route("/lytspel-on-one-page.pdf", methods=['GET'])
-def one_page_pdf() -> Response:
+@app.route("/lytspel-on-two-pages.pdf", methods=['GET'])
+def two_page_pdf() -> Response:
     """Serve the requested PDF document."""
     log_web_event()
-    return send_file('../docs/lytspel-on-one-page.pdf', mimetype='application/pdf')
+    return send_file('../docs/lytspel-on-two-pages.pdf', mimetype='application/pdf')
 
 
 @app.route("/robots.txt", methods=['GET'])
@@ -452,14 +465,14 @@ def log_web_event(msg: str = None, *args):
     msg += ' (user agent: %s)'
     agent = request.user_agent
     agent_string = '{}/{} {}'.format(
-        agent.platform or '-', agent.browser or '-', agent.version or '-')
+        agent.platform or '-', agent.browser or '-', agent.version or '-')  # type: ignore
 
     if agent_string == '-/- -':
         # Log the raw User-Agent header instead (if sent)
         agent_string = '"{}"'.format(agent.string or '')
 
     args = (*args, agent_string)
-    app.logger.info(msg, *args)
+    LOG.info(msg, *args)
 
 
 def redirect_with_error(msg: str, url: str = '/') -> Response:
